High-level interfaces
=====================

.. currentmodule:: chaospy

Orthogonal expansion
--------------------

.. autosummary::
   :toctree: ../api

   generate_expansion

Quadrature
----------

.. autosummary::
   :toctree: ../api

   generate_quadrature

Fit chaos expansion
-------------------

.. autosummary::
   :toctree: ../api

   fit_regression
   fit_quadrature

Three terms recurrence coefficients
-----------------------------------

.. autosummary::
   :toctree: ../api

   construct_recurrence_coefficients
